package agents;

import java.io.Serializable;
import java.math.BigDecimal;

import simulator.constants.ComponentName;

/**
 * Class for representing an alarm from the agent system to the operator.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class AgentAlarm implements Serializable {

	private static final long serialVersionUID = 1L;

	private AgentName agentName;
	private int componentId;
	private int time;
	private BigDecimal value;
	private String text;
	
	public AgentAlarm(AgentName agentName, int componentId, int time, BigDecimal value, String text) {
		this.agentName = agentName;
		this.componentId = componentId;
		this.time = time;
		this.value = value;
		this.text = text;
	}
	
	public AgentName getAgentName() {
		return agentName;
	}

	public int getTime() {
		return time;
	}

	public BigDecimal getValue() {
		return value;
	}

	public String getText() {
		return text;
	}

	public int getComponentId() {
		return componentId;
	}

	public boolean equals(Object alarm) {
		AgentAlarm anotherAlarm = (AgentAlarm)alarm;
		return agentName == anotherAlarm.getAgentName();
	}
	
	/**
	 * TODO insert component name instead of id
	 */
	public String toString() {
		StringBuffer content = new StringBuffer();
		content.append(agentName.getName());
		content.append(" reports of ");
		content.append(text);
		content.append(" (" + value + ") ");
		content.append("in ");
		content.append(ComponentName.getComponentName(componentId).getLongname());
		return content.toString();
	}
	
}
