package agents;

import java.awt.Color;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;

import javax.swing.JTextPane;
import javax.swing.text.BadLocationException;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledDocument;

import simulator.Clock;
import aos.jack.jak.agent.Agent;

/**
 * This class enables us to change the standard out/err so that output is
 * written to the textpanes which is added to the interface when running in
 * agent mode. There is one such object for out, one for err.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class AgentOutputStream extends OutputStream {

	// The console
	private PrintStream originalOut;

	private StringBuffer contents;
	private JTextPane textPane;
	private Clock timekeeper;
	private Color color;

	public AgentOutputStream(PrintStream originalOut, JTextPane textPane, Color color) {
		this.originalOut = originalOut;
		this.contents = new StringBuffer("");
		this.textPane = textPane;
		this.timekeeper = Clock.getInstance();
		this.color = color;
	}

	/**
	 * Based on something I found on the Internet, more specifically here:
	 * http://mindterm.appgate.com/pipermail/mindterm-users/2001q4/000414.html
	 */
	@Override
	public void write(int b) throws IOException {
		byte[] buf = new byte[1];
		buf[0] = (byte) b;
		String s = new String(buf);
		contents.append(s);

		// We have reached the end of the line
		if ("\n".equals(s)) {
			String text = contents.toString();

			// Create string with current time and agent
			StringBuffer timeAgent = new StringBuffer();

			// Get current time
			int currentTime = timekeeper.getCurrentTime();
			if (currentTime >= 0) {
				// Get current agent
				SuperAgent currentAgent = (SuperAgent)Agent.getCurrentAgent();
				timeAgent.append("[");
				if (currentAgent != null) {
					timeAgent.append(currentAgent.getCode()+ " ");
				}
				timeAgent.append("T");
				
				if (currentTime < 10) {
					timeAgent.append("0");
				}
				timeAgent.append(currentTime + "] ");
			}
			String completeLine = timeAgent + text;
			
			if(textPane != null) {
				writeToGUI(completeLine);
			}
			originalOut.append(completeLine);
			contents.setLength(0);
		}
	}
	
	/*
	 * Method for writing to the graphical user interface
	 */
	public void writeToGUI(String text) {
		StyledDocument doc = (StyledDocument) textPane.getDocument();
		Style style = doc.addStyle("Current style", null);
		StyleConstants.setFontFamily(style, "Courier New");
		StyleConstants.setFontSize(style, 11);
		StyleConstants.setForeground(style, color);
		try {
			doc.insertString(doc.getLength(), text, style);
		} catch (BadLocationException e) {
			System.out
					.println("BadLocationException when trying to write to log panel");
			e.printStackTrace();
		}
		textPane.setCaretPosition(textPane.getDocument().getLength());
	}

	
}
