package simulator.config;

import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SpringLayout;

import simulator.constants.Constants;

/**
 * Panel for displaying the configurable database options for a testcase.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class DatabaseConfigPanel extends JPanel implements Constants {

	private static final long serialVersionUID = 1L;

	private final String TITLE = "Database";
	private final int SPACING = 4;
	
	private SpringLayout layout;
	
	private JLabel hostLabel, databaseLabel, usernameLabel, passwordLabel;
	protected JComboBox hostField, databaseField, usernameField, passwordField;
	
	private String[] hostOptions = {"mysql.stud.ntnu.no", "localhost"};
	private String[] databaseOptions = {"liselene_master"};
	private String[] usernameOptions = {"liselene_master"};
	private String[] passwordOptions = {"Agenter"};
	
	/**
	 * Constructor. Initialize the components.
	 */
	public DatabaseConfigPanel() {
		layout = new SpringLayout();
		setLayout(layout);
		setBorder(BorderFactory.createTitledBorder(TITLE));
		addComponents();
	}
	
	/**
	 * Method which creates and adds components to the panel.
	 */
	public void addComponents() {
		hostLabel = new JLabel("Host");
		databaseLabel = new JLabel("Database");
		usernameLabel = new JLabel("Username");
		passwordLabel = new JLabel("Password");
		
		hostField = new JComboBox(hostOptions);
		hostField.setEditable(true);
		databaseField = new JComboBox(databaseOptions);
		databaseField.setEditable(true);
		usernameField = new JComboBox(usernameOptions);
		usernameField.setEditable(true);
		passwordField = new JComboBox(passwordOptions);
		passwordField.setEditable(true);
		
		add(hostLabel);
		add(hostField);
		layout.putConstraint(W, hostLabel, SPACING, W, this);
		layout.putConstraint(N, hostLabel, SPACING, N, this);
		layout.putConstraint(E, hostField, -SPACING, E, this);
		layout.putConstraint(N, hostField, SPACING, N, this);

		add(databaseLabel);
		add(databaseField);
		layout.putConstraint(W, databaseLabel, SPACING, W, this);
		layout.putConstraint(N, databaseLabel, SPACING, S, hostField);
		layout.putConstraint(E, databaseField, -SPACING, E, this);
		layout.putConstraint(N, databaseField, SPACING, S, hostField);

		add(usernameLabel);
		add(usernameField);
		layout.putConstraint(W, usernameLabel, SPACING, W, this);
		layout.putConstraint(N, usernameLabel, SPACING, S, databaseField);
		layout.putConstraint(E, usernameField, -SPACING, E, this);
		layout.putConstraint(N, usernameField, SPACING, S, databaseField);
		
		add(passwordLabel);
		add(passwordField);
		layout.putConstraint(W, passwordLabel, SPACING, W, this);
		layout.putConstraint(N, passwordLabel, SPACING, S, usernameField);
		layout.putConstraint(E, passwordField, -SPACING, E, this);
		layout.putConstraint(N, passwordField, SPACING, S, usernameField);

		layout.putConstraint(S, this, SPACING, S, passwordField);
	}
	
}
