package simulator.config;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.JCheckBox;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.SpringLayout;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import simulator.constants.Constants;

/**
 * Panel for displaying the configurable system options for a testcase.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class SystemConfigPanel extends JPanel implements Constants, ChangeListener {

	private static final long serialVersionUID = 1L;

	private final String TITLE = "System";
	private final int SPACING = 4;
	
	private SpringLayout layout;
	
	protected JCheckBox agentClean, agentCompile;
	
	protected ButtonGroup modeButtonGroup;
	protected JRadioButton agentMode, manualMode;

	/**
	 * Constructor. Initializes the components.
	 */
	public SystemConfigPanel() {
		layout = new SpringLayout();
		setLayout(layout);
		setBorder(BorderFactory.createTitledBorder(TITLE));
		addComponents();
	}
	
	/**
	 * Method which creates and adds all components to the panel
	 */
	public void addComponents() {
		
		agentMode = new JRadioButton("Agent mode");
		agentMode.setSelected(true);
		manualMode = new JRadioButton("Manual mode");

		agentMode.addChangeListener(this);
		manualMode.addChangeListener(this);

		modeButtonGroup = new ButtonGroup();
		modeButtonGroup.add(agentMode);
		modeButtonGroup.add(manualMode);
		
		add(manualMode);
		layout.putConstraint(W, manualMode, SPACING, W, this);
		layout.putConstraint(N, manualMode, SPACING, N, this);

		add(agentMode);
		layout.putConstraint(W, agentMode, SPACING, W, this);
		layout.putConstraint(N, agentMode, SPACING, S, manualMode);

		agentClean = new JCheckBox("Clean agents");
		agentCompile = new JCheckBox("Compile agents");

		if(StartupScreen.DEV) {
			add(agentClean);
			layout.putConstraint(W, agentClean, SPACING, W, this);
			layout.putConstraint(N, agentClean, SPACING - 3, S, agentMode);

			add(agentCompile);
			layout.putConstraint(W, agentCompile, SPACING, W, this);
			layout.putConstraint(N, agentCompile, SPACING - 3, S, agentClean);

			layout.putConstraint(S, this, SPACING, S, agentCompile);
		} else {
			layout.putConstraint(S, this, SPACING, S, agentMode);
		}
	}

	@Override
	public void stateChanged(ChangeEvent event) {
		if(event.getSource() == agentMode && StartupScreen.DEV) {
			if(agentMode.isSelected()){
				agentClean.setEnabled(true);
				agentCompile.setEnabled(true);
			} else {
				agentClean.setSelected(false);
				agentClean.setEnabled(false);
				agentCompile.setSelected(false);
				agentCompile.setEnabled(false);
			}
		}
	}
}
