package simulator.constants;

/**
 * Enum for the names of the various modules of the user interface. 
 * This includes the components of the oil field. Number of wells in
 * system is not necessarily correct here..
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public enum ComponentName {

	TESTCASE("Current testcase", "Testcase", "T", -1), 
	INPUT("Operator input", "Input", "I", -1), 
	FIELD("Oil field", "Field", "F", -1), 
	PLANT("Processing plant", "Plant", "Pl", 0), 
	WELL1("Well 1", "Well1", "W1", 1), 
	WELL2("Well 2", "Well2", "W2", 2), 
	WELL3("Well 3","Well3", "W3", 3), 
	WELL4("Well 4", "Well4", "W4", 4), 
	OUTPUT("System output", "Output", "O", -1),
	NOT_RECOGNISED("Component not recognised", "ComponentX", "CX", -1);

	private String longname;
	private String shortname;
	private String code;
	private int id;

	private ComponentName(String longname, String shortname, String code, int id) {
		this.longname = longname;
		this.shortname = shortname;
		this.code = code;
		this.id = id;
	}

	/**
	 * Method which returns the correct ModuleName for a well with the given id.
	 * 
	 * @param id The unique id of the well
	 * @return The module name of the given well
	 */
	public static ComponentName getWellModuleName(int id) {
		switch (id) {
		case 1:
			return WELL1;
		case 2:
			return WELL2;
		case 3:
			return WELL3;
		case 4:
			return WELL4;
		default:
			return NOT_RECOGNISED;
		}
	}

	/**
	 * Method which returns the well number of a given module name, -1 if not found.
	 * 
	 * @param name the name of a well
	 * @return the id of the given name, -1 if not found
	 */
	public static int getWellModuleNumber(ComponentName name) {
		int id = -1;
		for (int i = 0; i < 5; i++) {
			if (name == getWellModuleName(i)) {
				id = i;
			}
		}
		return id;
	}
	
	public static ComponentName getComponentName(int id) {
		switch (id) {
		case 0:
			return PLANT;
		case 1:
			return WELL1;
		case 2:
			return WELL2;
		case 3:
			return WELL3;
		case 4:
			return WELL4;
		default:
			return NOT_RECOGNISED;
		}
	}

	/**
	 * Method for checking whether this module name belongs to a well
	 * 
	 * @return true if this is a well, false if not
	 */
	public boolean isWell() {
		return this == WELL1 || this == WELL2 || this == WELL3 || this == WELL4;
	}

	public String getLongname() {
		return longname;
	}

	public String getShortname() {
		return shortname;
	}
	
	public String getCode() {
		return code;
	}
	
	public int getId(){
		return id;
	}
}
