package simulator.controlroom;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SpringLayout;

import simulator.constants.ComponentName;
import simulator.constants.Constants;

/**
 * An abstract class for all "oil producing panels", i.e. the wells,
 * the plant and the field itself. Defines common characteristics and
 * behaviour like the color they get when they are selected etc.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public abstract class OilProductionPanel extends JPanel implements Constants {

	protected ComponentName name;
	protected JLabel nameLabel;
	protected SpringLayout layout;

	protected Color currentBackgroundColor;

	/**
	 * Constructor. Initiliazes the variables and adds the name label.
	 * 
	 * @param name the name of the component
	 * @param size the size of this panel
	 */
	public OilProductionPanel(ComponentName name, Dimension size) {
		this.name = name;
		setPreferredSize(size);
		layout = new SpringLayout();
		setLayout(layout);
		
		// Add the name label
		nameLabel = new JLabel(name.getLongname());
		nameLabel.setFont(new Font("Dialog", Font.PLAIN, 15));
		add(nameLabel);
		layout.putConstraint(N, nameLabel, 5, N, this);
		layout.putConstraint(W, nameLabel, 10, W, this);
		
		unselect();
	}

	/**
	 * Method called when this component has been selected in the GUI
	 */
	protected void select() {
		currentBackgroundColor = SELECTED_BACKGROUND;
		setBorder(BorderFactory.createLineBorder(Color.BLACK));
		repaint();
	}

	/**
	 * Method called when another component has been selected in the GUI
	 */
	protected void unselect() {
		currentBackgroundColor = UNSELECTED_BACKGROUND;
		setBorder(BorderFactory.createLineBorder(Color.GRAY));
		repaint();
	}

	/**
	 * Method which returns the name of this panel
	 * @return the component name
	 */
	public ComponentName getComponentName() {
		return name;
	}

	/**
	 * Returns the long version of the component's name
	 */
	public String toString() {
		return name.getLongname();
	}

	/**
	 * Paints the panel with the current background color
	 */
	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		g.setColor(currentBackgroundColor);
		g.fillRect(0, 0, getPreferredSize().width, getPreferredSize().height);
	}
}
