/**
 * 
 */
package simulator.controlroom;

import javax.swing.JScrollPane;
import javax.swing.JTextPane;
import javax.swing.ScrollPaneConstants;
import javax.swing.text.BadLocationException;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledDocument;

import simulator.constants.LogLevel;
import simulator.constants.ComponentName;

/**
 * Objects of this class constitute the output tabs in the lower part
 * of the screen. There is one such tab for each component of the field,
 * as well as a common one which displays all messages.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class OutputTab extends JScrollPane {

	private static final long serialVersionUID = 1L;

	// The name of the component to which this tab belongs
	private ComponentName name;
	// Where the actual text is written
	private JTextPane textPane;

	/**
	 * Constructor.
	 * @param name the name of the component this tab receives output from
	 */
	public OutputTab(ComponentName name) {
		this.name = name;
		setWheelScrollingEnabled(true);
		setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
		textPane = new JTextPane();
		textPane.setEditable(false);
		setViewportView(textPane);
	}

	/**
	 * Method which writes a given log message to the screen. The formatting of
	 * the message depends on the socalled "log level" of the message.
	 * 
	 * @param status whether this is for information or error
	 * @param message the message to be displayed
	 */
	public void write(LogLevel status, String message) {
		StyledDocument doc = (StyledDocument) textPane.getDocument();
		Style style = doc.addStyle("Current style", null);
		StyleConstants.setFontFamily(style, "Courier New");
		StyleConstants.setFontSize(style, 11);
		StyleConstants.setForeground(style, status.getColor());
		try {
			doc.insertString(doc.getLength(), message + "\n", style);
		} catch (BadLocationException e) {
			System.out.println("BadLocationException when trying to write to log panel");
			e.printStackTrace();
		}
		textPane.setCaretPosition(textPane.getDocument().getLength());
	}

	/**
	 * Method which returns the name of the component to which this tab belongs
	 * @return the component name
	 */
	public ComponentName getComponentName() {
		return name;
	}

	/** 
	 * Method which returns the long version of the component's name
	 * @return the component name
	 */
	public String toString() {
		return name.getLongname();
	}

}
