package simulator.controlroom;

import java.awt.Dimension;
import java.awt.event.MouseListener;

import javax.swing.text.BadLocationException;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledDocument;

import simulator.field.Plant;
import simulator.field.Sensors;
import simulator.util.NumberFormatter;

/**
 * Panel for displaying the current sensor values for the plant. In addition to textual 
 * representations of the sensor values, it also contains a bar which shows the 
 * amount of pure oil related to the amount of residual products in the production. The
 * drawing of this diagram is done in the superclass.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class PlantPanel extends FieldComponentPanel {

	private static final long serialVersionUID = 1L;

	/**
	 * Constructor. Sends most of its parameters on to the superclass.
	 * @param listener for reacting to mouse clicks
	 * @param plant the plant to which this panel belongs
	 * @param size the dimension of this plant panel
	 */
	public PlantPanel(MouseListener listener, Plant plant, Dimension size) {
		super(listener, plant, size);
		displayInfo();
		setVisible(true);
	}

	/**
	 * Method which retrieves the current sensor values from the well and
	 * displays them. Also makes sure that the panel is repainted so that
	 * the diagram visualising the production is updated.
	 */
	public void displayInfo() {
		Plant plant = (Plant)component;
		
		Sensors sensors = plant.getSensors();
		StringBuffer content = new StringBuffer();
		
		int width = 23;
		
		content.append("Current\n");
		content.append(NumberFormatter.formatOutput(" Production", width, sensors.getProductionValue()) + "\n");
		content.append(NumberFormatter.formatOutput(" Oil content", width, sensors.getOilValue()) + "\n");
		content.append(NumberFormatter.formatOutput(" Water content", width, sensors.getWaterValue()) + "\n");
		
		content.append("Total\n");
		content.append(NumberFormatter.formatOutput(" Production", width, plant.getTotalQuantityProduced()) + "\n");
		content.append(NumberFormatter.formatOutput(" Oil content", width, plant.getTotalOilProduction()) + "\n");
		content.append(NumberFormatter.formatOutput(" Water content", width, plant.getTotalWaterProduction()) + "\n");

		StyledDocument doc = infoPane.getStyledDocument();
		Style style = doc.addStyle("Current style", null);
		StyleConstants.setFontFamily(style, "Courier New");
		try {
			doc.remove(0, doc.getLength());
			doc.insertString(doc.getLength(), content.toString(), style);
		} catch (BadLocationException e) {
			System.out.println("When displaying info in PlantPanel: " + e.getMessage());
			e.printStackTrace();
		}
		repaint();
	}
}
