package simulator.db;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * Class for setting up a connection to the database
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 *
 */
public class Database {

	private final String DRIVER = "org.gjt.mm.mysql.Driver";

	// These fields are set by the startup screen
	private static String url = "";
	private static String database = "";
	private static String username = "";
	private static String password = "";

	private Connection connection = null;

	/**
	 * Constructor. Initializes the connection.
	 */
	public Database() {
		try {
			Class.forName(DRIVER).newInstance();
			connection = DriverManager.getConnection(url + database, username, password);
		} catch (SQLException e) {
			System.out.println("Could not connect to database. Is your Internet connection working?");
			System.exit(0);
		} catch (InstantiationException e) {
			e.printStackTrace();
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		} catch (ClassNotFoundException e) {
			e.printStackTrace();
		}
	}

	/**
	 * Method used for running queries where a result set should be returned
	 * 
	 * @param query the query to be run
	 * @return the result of the query
	 */
	public ResultSet runExecuteQuery(String query) {
		ResultSet rs = null;
		try {
			Statement st = connection.createStatement();
			rs = st.executeQuery(query);
		} catch (SQLException e) {
			System.out.println("Problems when running an execute query");
			e.printStackTrace();
		}
		return rs;
	}

	/**
	 * Method used for running update queries
	 * @param query the query to be run
	 */
	public void runUpdateQuery(String query) {
		try {
			Statement st = connection.createStatement();
			st.executeUpdate(query);
		} catch (SQLException e) {
			System.out.println("Problems when running an update query");
			e.printStackTrace();
		}
	}

	/**
	 * Method for closing the database connection
	 */
	public void close() {
		try {
			connection.close();
		} catch (SQLException e) {
			System.out.println("Fikk ikke til  lukke databasen:(");
			e.printStackTrace();
		}
	}

	public static void setUrl(String host) {
		Database.url = "jdbc:mysql://" + host + "/";
	}

	public static void setDatabase(String database) {
		Database.database = database;
	}

	public static void setUsername(String username) {
		Database.username = username;
	}

	public static void setPassword(String password) {
		Database.password = password;
	}

}
