package simulator.field;

import simulator.constants.ChokeAdjuster;

/**
 * Class which represents a change of choke position.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class ChokePositionChange {

	private ChokeAdjuster adjuster;
	private Well adjustedWell;
	private int time;
	private int chokePosition;
	
	/**
	 * Constructor. Initializes the fields.
	 * @param adjuster who made the adjustment to begin with
	 * @param adjustedWell which well the choke belongs to
	 * @param time when the adjustment was made
	 * @param chokePosition the new position of the choke
	 */
	public ChokePositionChange(ChokeAdjuster adjuster, Well adjustedWell, int time, int chokePosition) {
		this.adjuster = adjuster;
		this.adjustedWell = adjustedWell;
		this.time = time;
		this.chokePosition = chokePosition;
	}

	/**
	 * @return true if the change needs attention from the agents, false if not
	 */
	public boolean forAgent() {
		return ChokeAdjuster.OPERATOR == adjuster;
	}
	
	/**
	 * @return true if the change needs attention from the slider, false if not
	 */
	public boolean forSlider() {
		return ChokeAdjuster.AGENT == adjuster || ChokeAdjuster.INSTRUCTION == adjuster;
	}
	
	public ChokeAdjuster getAdjuster() {
		return adjuster;
	}
	public void setAdjuster(ChokeAdjuster adjuster) {
		this.adjuster = adjuster;
	}
	public int getTime() {
		return time;
	}
	public void setTime(int time) {
		this.time = time;
	}
	public int getChokePosition() {
		return chokePosition;
	}
	public void setChokePosition(int chokePosition) {
		this.chokePosition = chokePosition;
	}

	public Well getAdjustedWell() {
		return adjustedWell;
	}

	public void setAdjustedWell(Well adjustedWell) {
		this.adjustedWell = adjustedWell;
	}
	
	public String getAdjustedWellName() {
		return adjustedWell.getName().getShortname();
	}
	
}
