package simulator.field;

import java.util.ArrayList;
import java.util.List;
import java.util.Observable;
import java.util.Observer;


/**
 * Class for a set of chokes. Introduced because the operator agent
 * needs to be able to monitor all the chokes at the same time.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class ChokeSet extends Observable implements Observer {
	
	private List<Choke> chokes;
	private ChokePositionChange latestChange;
	
	public ChokeSet(){
		chokes = new ArrayList<Choke>();
	}
	
	public void addChoke(Choke choke) {
		chokes.add(choke);
		choke.addObserver(this);
	}

	@Override
	public void update(Observable arg0, Object c) {
		latestChange = (ChokePositionChange)c;
		if(latestChange.forAgent()) {
			setChanged();
			notifyObservers();
			clearChanged();
		}
	}
	
	public ChokePositionChange getLatestChange() {
		return latestChange;
	}

}
