package simulator.field;

import java.math.BigDecimal;

import simulator.Clock;
import simulator.constants.ComponentName;
import simulator.constants.Constants;
import simulator.db.Writer;

/**
 * Abstract class for all components in a field, i.e. all components involved in
 * oil production except the field itself
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public abstract class FieldComponent extends OilProductionComponent implements Constants{

	protected Sensors sensors;
	protected BigDecimal maxProduction;
	protected boolean inCriticalSituation;
	
	// For logging critical situations to the database
	protected Writer writer = Writer.getInstance();
	// For getting the current time 
	protected Clock timekeeper = Clock.getInstance();

	public FieldComponent(ComponentName name) {
		super(name);
		sensors = new Sensors();
	}

	public Sensors getSensors() {
		return sensors;
	}

	public BigDecimal getMaxProduction() {
		return maxProduction;
	}
	
	public String toString() {
		return name.getLongname();
	}
	
	public boolean inCriticalSituation() {
		return inCriticalSituation;
	}
}
