package simulator.field;

import java.math.BigDecimal;

import simulator.constants.SensorType;
import simulator.db.Writer;

/**
 * Sensors belonging to a plant
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class PlantSensors extends Sensors{

	// The plant these sensors belong to
	private Plant plant;
	// Used for logging sensor values to database
	private Writer writer = Writer.getInstance();

	/**
	 * Constructor
	 * @param plant the plant these sensors belong to
	 */
	public PlantSensors(Plant plant) {
		this.plant = plant;
	}
	
	/**
	 * Method used to create the sensor values "measured" in the processing
	 * plant. In reality, these are the sums of the well sensor values. A
	 * notification is sent to the observers of the plant when the values
	 * have been changed.
	 * 
	 * @param production
	 * @param water
	 * @param sand
	 */
	public void setSensorValues(int time, BigDecimal production, BigDecimal water, BigDecimal sand) {
		this.production = new SensorReading(time, production);
		writer.logSensorValue(time, plant.name, SensorType.PRODUCTION, production);
		this.oil = new SensorReading(time, production.subtract(water).subtract(sand));
		this.water = new SensorReading(time, water);
		writer.logSensorValue(time, plant.name, SensorType.WATER, water);
		this.sand = new SensorReading(time, sand);
		writer.logSensorValue(time, plant.name, SensorType.SAND, sand);
		setChanged();
		notifyObservers();
		clearChanged();
	}

}
