package simulator.field;

import java.math.BigDecimal;
import java.util.Observable;

import simulator.util.NumberFormatter;

/**
 * Class defining the common characteristics for all kinds of sensor sets.
 * 
 * @author Lene Hallen
 * @author Lise Engmo
 */
public class Sensors extends Observable {

	protected int time;
	
	protected SensorReading production;
	protected SensorReading oil;
	protected SensorReading water;
	protected SensorReading sand;
	
	/**
	 * Constructor
	 */
	public Sensors() {
		this.time = -1;
		this.production = new SensorReading();
		this.oil = new SensorReading();
		this.water = new SensorReading();
		this.sand = new SensorReading();
	}

	/**
	 * @return the current production reading
	 */
	public SensorReading getProductionReading() {
		return production;
	}
	
	/**
	 * @return the current production
	 */
	public BigDecimal getProductionValue() {
		return production.getValue();
	}

	/**
	 * @return the current oil reading
	 */
	public SensorReading getOilReading() {
		return oil;
	}
	
	/**
	 * @return the current oil
	 */
	public BigDecimal getOilValue() {
		return oil.getValue();
	}
	
	/**
	 * @return the current water sensor reading
	 */
	public SensorReading getWaterReading() {
		return water;
	}

	/**
	 * @return the current water
	 */
	public BigDecimal getWaterValue() {
		return water.getValue();
	}
	
	/**
	 * @return the current sand sensor reading
	 */
	public SensorReading getSandReading() {
		return sand;
	}
	
	/**
	 * @return the current sand
	 */
	public BigDecimal getSandValue() {
		return sand.getValue();
	}
	
	/**
	 * Method meant to display the values of the sensor readings nicely..
	 */
	public String toString() {
		StringBuffer ret = new StringBuffer();
		
		int time = production.getTime();
		String timeString = "T";
		if(time < 10){
			timeString += (time + "  "); 
		} else if(time < 100) {
			timeString += (time + " ");
		} else if(time < 1000) {
			timeString += (time + "");
		}
		
		ret.append(timeString);
		
		String spaceBeforePrefix = "    ";
		ret.append(NumberFormatter.formatOutput(spaceBeforePrefix + "Production", 20, production.getValue()));
		ret.append(NumberFormatter.formatOutput(spaceBeforePrefix + "Oil", 13, oil.getValue()));
		ret.append(NumberFormatter.formatOutput(spaceBeforePrefix + "Water", 14, water.getValue()));
		ret.append(NumberFormatter.formatOutput(spaceBeforePrefix + "Sand", 13, sand.getValue()));

		return ret.toString();
	}
	
}
