package simulator.util;

import java.math.BigDecimal;
import java.math.RoundingMode;

public class NumberFormatter {

	/**
	 * Method used for formatting doubles, numbers are rounded to 2 decimals
	 * 
	 * @param prefix the first word of the output
	 * @param length the desired total length of the output
	 * @param value the value to insert at the end
	 * @return the formatted string
	 */
	public static String formatOutput(String prefix, int length, BigDecimal value){
		BigDecimal roundedNumber = value.setScale(2, RoundingMode.HALF_EVEN);
		String roundedNumberString = roundedNumber.toString().trim();
		int charCount = prefix.trim().length() + roundedNumberString.length();
		String spaces = "";
		for(int i = 0; i < (length-charCount); i++){
			spaces += ".";
		}
		return prefix + spaces + roundedNumberString;
	}

	/**
	 * Method used for formatting ints
	 * 
	 * @param prefix the first word of the output
	 * @param length the desired total length of the output
	 * @param value the value to insert at the end
	 * @return the formatted string
	 */
	public static String formatOutput(String prefix, int length, int value){
		int numberCount = 1;
		if(value > 9) {
			numberCount = 2;
		} else if (value > 99) {
			numberCount = 3;
		}
		int charCount = prefix.length() + numberCount;
		String spaces = "";
		for(int i = 0; i < (length-charCount); i++){
			spaces += ".";
		}
		return prefix + spaces + value;
	}
	
	/**
	 * @param value the number to be formatted
	 * @return the number rounded to two decimals
	 */
	public static String bigDecimalToString(BigDecimal value) {
		BigDecimal roundedValue = value.setScale(2, RoundingMode.HALF_EVEN);
		return roundedValue.toString().trim();
	}
	
}
